class BypassUnsubscribeManagement(object):
    """Setting for Bypass Unsubscribe Management


    Allows you to bypass the global unsubscribe list to ensure that the email is delivered to recipients.
    Bounce and spam report lists will still be checked; addresses on these other lists will not receive
    the message. This filter applies only to global unsubscribes and will not bypass group unsubscribes.
    This filter cannot be combined with the bypass_list_management filter.
    """

    def __init__(self, enable=None):
        """Create a BypassUnsubscribeManagement.

        :param enable: Whether emails should bypass unsubscribe management.
        :type enable: boolean, optional
        """
        self._enable = None

        if enable is not None:
            self.enable = enable

    @property
    def enable(self):
        """Indicates if this setting is enabled.

        :rtype: boolean
        """
        return self._enable

    @enable.setter
    def enable(self, value):
        """Indicates if this setting is enabled.

        :param value: Indicates if this setting is enabled.
        :type value: boolean
        """
        self._enable = value

    def get(self):
        """
        Get a JSON-ready representation of this BypassUnsubscribeManagement.

        :returns: This BypassUnsubscribeManagement, ready for use in a request body.
        :rtype: dict
        """
        bypass_unsubscribe_management = {}
        if self.enable is not None:
            bypass_unsubscribe_management["enable"] = self.enable
        return bypass_unsubscribe_management



import io
import os
from distutils.file_util import copy_file
from setuptools import setup, find_packages


__version__ = None
with open('sendgrid/version.py') as f:
    exec(f.read())

def getRequires():
    deps = [
        'python_http_client>=3.2.1',
        'starkbank-ecdsa>=2.0.1'
    ]
    return deps


dir_path = os.path.abspath(os.path.dirname(__file__))
readme = io.open(os.path.join(dir_path, 'README.rst'), encoding='utf-8').read()

setup(
    name='sendgrid',
    version=str(__version__),
    author='Elmer Thomas, Yamil Asusta',
    author_email='help@twilio.com',
    url='https://github.com/sendgrid/sendgrid-python/',
    packages=find_packages(exclude=["temp*.py", "test"]),
    include_package_data=True,
    license='MIT',
    description='Twilio SendGrid library for Python',
    long_description=readme,
    install_requires=getRequires(),
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
    classifiers=[
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ]
)



class BypassSpamManagement(object):
    """Setting for Bypass Spam Management

    Allows you to bypass the spam report list to ensure that the email is delivered to recipients.
    Bounce and unsubscribe lists will still be checked; addresses on these other lists will not
    receive the message. This filter cannot be combined with the bypass_list_management filter.
    """

    def __init__(self, enable=None):
        """Create a BypassSpamManagement.

        :param enable: Whether emails should bypass spam management.
        :type enable: boolean, optional
        """
        self._enable = None

        if enable is not None:
            self.enable = enable

    @property
    def enable(self):
        """Indicates if this setting is enabled.

        :rtype: boolean
        """
        return self._enable

    @enable.setter
    def enable(self, value):
        """Indicates if this setting is enabled.

        :param value: Indicates if this setting is enabled.
        :type value: boolean
        """
        self._enable = value

    def get(self):
        """
        Get a JSON-ready representation of this BypassSpamManagement.

        :returns: This BypassSpamManagement, ready for use in a request body.
        :rtype: dict
        """
        bypass_spam_management = {}
        if self.enable is not None:
            bypass_spam_management["enable"] = self.enable
        return bypass_spam_management
